@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 """
-     Copyright (C) 2002-2006 Stas Z. <stas@linux.isbeter.nl>
+     Copyright (C) 2002-2006 Stas Z. <stas.zytkiewicz@gmail.com>
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -108,9 +108,18 @@ except ImportError, info:
 # in his own thread.
 pygame.init()
 if CPDEBUG: print "mixer settings on init",pygame.mixer.get_init()
-        
-# Check if there's a childsplay dir in the home directory
-HOMEDIR = os.path.join(os.environ['HOME'],HOME_DIR_NAME)
+
+###### Moved into CPConstants ########
+### Check if there's a childsplay dir in the home directory
+##if sys.platform == 'win32':
+##    try:
+##      HOMEDIR = os.path.join(os.environ['HOMEDRIVE'],os.environ['HOMEPATH'],HOME_DIR_NAME)
+##    except:
+##        # for win 98 ??
+##        HOMEDIR = os.path.join(os.environ['HOMEPATH'],HOME_DIR_NAME)
+##else:
+##   HOMEDIR = os.path.join(os.environ['HOME'],HOME_DIR_NAME)
+
 tree = HOME_DIR_TREE.replace(';',os.sep)
 for piece in tree.split(','):
     piece = os.path.join(HOMEDIR,piece)
@@ -211,7 +220,7 @@ else:
 set_globalrc(rcdic)
 
 # i18n, put a lot of exception caches because locale stuff keeps crashing
-# on badly configured platforms. Mac OSX locale support is totally :-( 
+# on badly configured platforms. Mac OSX locale support is totally broken :-( 
 try:
     STDLOC,LOCALE_RTL = set_locale(LANG)
 except Exception,info:
@@ -219,7 +228,6 @@ except Exception,info:
     ChildsplayGoodies.language = 'en'
     STDLOC,LOCALE_RTL = 'en',None
 try:
-    #ChildsplayGoodies.language = STDLOC
     # Add support for the LANGUAGE env var.
     ChildsplayGoodies.language = STDLOC.split('@')[0].split('.')[0].split('_')[0]
 except Exception,info:
@@ -665,7 +673,7 @@ class Contr(Score):
                         v = item.update(event)
                         if v:
                             if v == 'questionmark':
-                                stop = self.get_help(obj,18)
+                                stop = self.get_help(obj,16)
                             elif v == 'score' and obj.__class__.__name__ == 'Game':
                                 stop = self.show_score(Misc.helptitle)
                             elif v == 'stop':
@@ -703,26 +711,50 @@ class Contr(Score):
         pygame.display.update(dirtyrects)
         clock = pygame.time.Clock() 
         stop = 0
+        key_map = None
+        if LOCALE_RTL and STDLOC:
+            key_map = {'he':he_key_map,
+                        'ar':ar_key_map}[STDLOC]
+        if STDLOC == 'ru': 
+            key_map = ru_key_map
         while stop == 0:
             clock.tick(30)
-            events = pygame.event.get()
-            for event in events:
-                if event.type is KEYDOWN and event.key == ord(_("y").lower()):
-                    self.sdim.dim(darken_factor=255,color_filter=(0,0,0))
-                    surf,size = font2surf(_("Shutting down....."),72,(207,55,48),self.ttf)
-                    Snd.mainmusic.stop()
-                    pygame.display.update(self.screen.blit(surf,(100,200)))
-                    threads = threading.enumerate()
-                    if len(threads) > 1:
-                        for t in threads[1:]:
-                            try:
-                                t._stop()# if it's the timer object
-                            except Exception,info:
-                                print info
-                                del(t)                    
-                    sys.exit(0)
-                elif event.type is KEYDOWN and not event.key == ord(_("y").lower()):
+            #events = pygame.event.get()
+            event = pygame.event.poll()
+            if event.type == KEYDOWN:
+                k = 0
+                m = pygame.key.get_mods()
+                # when using key_maps : < > and ? need special care (keys 59,47,46,44)
+                if LOCALE_RTL and event.key == 59 or event.key == 47 or \
+                    event.key == 46 or event.key == 44:
+                    k = event.key
+                elif m & KMOD_SHIFT:
+                    k = event.key-32
+                else:
+                    k = event.key
+                if not 31 < k < 127:
+                    continue
+                user_key = ord(map_keys(key_map,chr(k)))
+                if STDLOC in ['he','ar','ru']:
+                    endkey = ord(_("y"))
+                else:
+                    endkey = ord(_("y").lower())
+                if user_key != endkey:
                     stop = 1
+                    break
+                self.sdim.dim(darken_factor=255,color_filter=(0,0,0))
+                surf,size = font2surf(_("Shutting down....."),72,(207,55,48),self.ttf)
+                Snd.mainmusic.stop()
+                pygame.display.update(self.screen.blit(surf,(100,200)))
+                threads = threading.enumerate()
+                if len(threads) > 1:
+                    for t in threads[1:]:
+                        try:
+                            t._stop()# if it's the timer object
+                        except Exception,info:
+                            print info
+                            del(t)                    
+                sys.exit(0)
         self.sdim.undim()
         self.screen.set_clip(oldclip)
         return 0
@@ -763,7 +795,7 @@ class Contr(Score):
             txt.append(("               %s  %s%s%s" % (i,item[1]," - ",item[0])))
             i += 1
         obj = spam(name,txt)
-        self.get_help(obj,32)
+        self.get_help(obj,20)
         return 0
     
     def clear_scr(self,backgr=None):
@@ -786,7 +818,7 @@ class Contr(Score):
        
         pygame.time.wait(1500)
     
-    def get_help(self,obj,fsize=26):
+    def get_help(self,obj,fsize=24):
         """ Display the help text for the current game/plugin. It's using it's own eventloop.
           The text must be provided by the plugin."""
         if CPDEBUG: print "Starting get_help"
@@ -1014,3 +1046,4 @@ if __name__ == '__main__':
         main()
     finally:
         pass
+
