@@ -3,8 +3,8 @@
  #~ *            letters.py
  #~ *
  #~ *  Thu Oct 21 17:20:22 2004
- #~ *  Copyright  2004  Stas Z
- #~ *  stas@linux.isbeter.nl
+ #~ *  Copyright  2004-2006  Stas Z
+ #~ *  stas.zytkiewicz@gmail.com
  #~ ****************************************************************************/
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -46,7 +46,8 @@ def my_font2surf(word,size,fcol=None,ttf=None,sizel=None):
     It's used to prevent reversing of the characters when running in a
     RTL environment like Hebrew or Arabic.
     Letters.py uses only English in those environments because of unresolved
-    input issues. Contact me at stas@linux.isbeter.nl if you want info about this."""
+    input issues. Contact me at stas.zytkiewicz@gmail.com if you want info about this."""
+    #print ChildsplayGoodies.language
     if ChildsplayGoodies.language == 'he':
         if not fcol:
             fcol = (0,0,0)
@@ -208,7 +209,11 @@ class Game(Img,Snd):
         self.score = 0
         self.stop = 0
         for event in events:
-            if event.type is KEYDOWN and 96<event.key<123 :
+            # added swedish extended ascii å, ä and ö
+            if event.type is KEYDOWN and (96<event.key<123 or 
+                                            event.key==59 or
+                                            event.key==39 or
+                                            event.key==91) :
                 userkey = event.unicode
                 #print userkey
                 self._check_key(userkey[0])# when multiple keyes are pushed, len(userkey) > 1 ???
