@@ -4,7 +4,7 @@
  #~ *
  #~ *  Thu Oct 21 17:19:22 2004
  #~ *  Copyright  2004  Stas Z
- #~ *  stas@linux.isbeter.nl
+ #~ *  stas.zytkiewicz@gmail.com
  #~ ****************************************************************************/
 
 # This program is free software; you can redistribute it and/or modify
@@ -29,7 +29,7 @@ import os,sys,random,glob
 import pygame
 from pygame.constants import *
 from utils import load_image,load_sound,MyError,import_module,ScaleImages
-from CPConstants import HOME_DIR_NAME
+from CPConstants import HOMEDIR
 
 class Img:
     pass
@@ -46,7 +46,7 @@ class Game:
         self.screen = screen
         self.backgr = backgr
         self.rc_dic = rc_dic
-                
+        self.myimages = []      
         self.basedir  = basepath
         try:
             import pyassetmlSDL
@@ -64,7 +64,11 @@ class Game:
         self.libdir = libdir
         # This will also used as a test if we are using other images
         #self.myimages = glob.glob(os.path.join(self.libdir,'MemoryData','my_images','*'))
-        self.myimages = glob.glob(os.path.join(os.environ['HOME'],HOME_DIR_NAME,'memory','my_images','*'))
+        try:
+            self.myimages = glob.glob(os.path.join(HOMEDIR,'memory','my_images','*'))
+        except Exception,info:
+            print info
+            self.myimages = []
         if DEBUG: print "Contents of my_images", self.myimages
         if len(self.myimages) < 12:
             self.myimages = None
