@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-     Copyright (C) 2002-2004 Stas Z <stas@linux.isbeter.nl>
+     Copyright (C) 2002-2004 Stas Z <stas.zytkiewicz@gmail.com>
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@ import pygame,os,sys,fnmatch,traceback,operator,imp,glob,locale,\
 from pygame.constants import *
 from CPConstants import *
 
-DEBUG = 0
+UT_DEBUG = 0
 
 class MyError(Exception):
     name = None
@@ -65,8 +65,8 @@ def set_locale(lang=None):
     else:
         lang = lang.split('@')[0].split('.')[0].split('_')[0]
     # This is to signal that we running under a RTL locale like Hebrew or Arabic
-    # Only Hebrew is supported until now
-    if lang == 'he':
+    # Only Hebrew and Arabic is supported until now
+    if lang in ['he','ar']:
         if pyfribidi:
             LOCALE_RTL = True
         else:
@@ -106,9 +106,10 @@ def _check_LocaleIsRTL(seq):
     Returns -> tuple: ttf font to use, reversed seq.
     """
     rtl_ttf,rtl_seq = None,seq
-    # Only Hebrew is supported at this moment
+    # Hebrew and Arabic is supported
     try:
-        if  get_locale()[:2].split('@')[0].split('.')[0].split('_')[0] != "he":
+        loc =  get_locale()[:2].split('@')[0].split('.')[0].split('_')[0]
+        if loc not in ['he','ar']:
             return (None,seq)
     except Exception,info:
         print info
@@ -118,25 +119,36 @@ def _check_LocaleIsRTL(seq):
     if type(seq) is types.ListType:
         rtl_seq = []
         for line in seq:
-            if DEBUG:
+            if UT_DEBUG:
                 print "from gettext",line.encode('utf-8')
                 print "from pyfribidi",pyfribidi.log2vis(line.encode('utf-8'))
             rtl_seq.append(unicode(pyfribidi.log2vis(line.encode('utf-8')),'utf-8'))
     else:
-        if DEBUG:
+        if UT_DEBUG:
             print "from gettext",seq.encode('utf-8')
             print "from pyfribidi",pyfribidi.log2vis(seq.encode('utf-8'))
         rtl_seq = unicode(pyfribidi.log2vis(seq.encode('utf-8')),'utf-8')
-    if os.path.exists('/usr/share/fonts/truetype/freefont/FreeSans.ttf'):
-        rtl_ttf = '/usr/share/fonts/truetype/freefont/FreeSans.ttf'
-    elif os.path.exists('/usr/local/share/fonts/truetype/freefont/FreeSans.ttf'):
-        rtl_ttf = '/usr/local/share/fonts/truetype/freefont/FreeSans.ttf'
-    elif os.path.exists(os.path.join(DATADIR,'he.ttf')):
-        rtl_ttf = os.path.join(DATADIR,'he.ttf')
-    else:
-        print "No suitable fonset found for your locale"
-        rtl_ttf = None
-    if DEBUG: print "using fontset %s \nfor RTL locale" % rtl_ttf
+    if loc == 'he':
+        if os.path.exists('/usr/share/fonts/truetype/freefont/FreeSans.ttf'):
+            rtl_ttf = '/usr/share/fonts/truetype/freefont/FreeSans.ttf'
+        elif os.path.exists('/usr/local/share/fonts/truetype/freefont/FreeSans.ttf'):
+            rtl_ttf = '/usr/local/share/fonts/truetype/freefont/FreeSans.ttf'
+        elif os.path.exists(os.path.join(DATADIR,'he.ttf')):
+            rtl_ttf = os.path.join(DATADIR,'he.ttf')
+        else:
+            print "No suitable fonset found for your locale"
+            rtl_ttf = None
+    elif loc == 'ar':
+        if os.path.exists('usr/share/fonts/truetype/ttf-arabeyes/ae_AlMohanad.ttf'):
+            rtl_ttf = 'usr/share/fonts/truetype/ttf-arabeyes/ae_AlMohanad.ttf'
+        elif os.path.exists('usr/share/fonts/truetype/ttf-arabeyes/ae_AlMohanad.ttf'):
+            rtl_ttf = 'usr/share/fonts/truetype/ttf-arabeyes/ae_AlMohanad.ttf'
+        elif os.path.exists(os.path.join(DATADIR,'ae_AlMohanad.ttf')):
+            rtl_ttf = os.path.join(DATADIR,'ae_AlMohanad.ttf')
+        else:
+            print "No suitable fonset found for your locale"
+            rtl_ttf = None
+    if UT_DEBUG: print "using fontset %s \nfor RTL locale" % rtl_ttf
     return (rtl_ttf,rtl_seq)
 
 def read_unicode_file(path):
@@ -144,8 +156,6 @@ def read_unicode_file(path):
     file = []
     try:
         f = codecs.open(path, 'r',encoding='utf-8')
-##        for line in f:
-##            file.append(repr(line))
         file = f.readlines()
     except Exception,info:
         return None
@@ -181,6 +191,8 @@ class NoneSound:
         pass
     def stop(self):
         pass
+    def queue(self):
+        pass
     def __eq__(self,other):
         if other == 'NoneSound': return True
         else: return False
@@ -188,20 +200,32 @@ class NoneSound:
         if other != 'NoneSound': return True
         else: return False
 
+class MusicObject:
+        """This is a wrapper around pygame.music"""
+        def __init__(self,filename):
+            self.s = filename
+        def play(self,loop=0):
+            pygame.mixer.music.load(self.s)
+            pygame.mixer.music.play(loop)
+        def stop(self):
+            pygame.mixer.music.stop()
+        def queue(self):
+            pygame.mixer.music.queue(self.s)
+
 def load_sound(name):
     """Loads a sound -> pygame sound object.
       If no file can be loaded return a dummy class"""
                 
     if not pygame.mixer or not pygame.mixer.get_init():
         print >> sys.stderr, 'Cannot load sound: %s \n%s\n pygame.mixer.error' % (name,pygame.get_error())
-        
         print >> sys.stderr, 'Using Nonesound'
         return NoneSound()
     try:
         sound = pygame.mixer.Sound(name)
     except pygame.error, message:
-        print >> sys.stderr, 'Cannot load sound: %s \n%s' % (name,pygame.get_error())
-        print >> sys.stderr, 'Using Nonesound'
+        if UT_DEBUG:
+            print >> sys.stderr, 'Cannot load sound: %s \n%s' % (name,pygame.get_error())
+            print >> sys.stderr, 'Using Nonesound'
         return NoneSound()
     return sound
 
@@ -212,31 +236,19 @@ def load_music(file):
      music source. This function returns a filename wrapped in a sound like object with
      a play and stop method.
      For multiple sources use the pygame.Sound and wave combination.
-     """
-    class MusicObject:
-        def __init__(self,filename):
-            self.s = filename
-        def play(self,loop=0):
-            pygame.mixer.music.load(self.s)
-            pygame.mixer.music.play(loop)
-        def stop(self):
-            pygame.mixer.music.stop()
-    def queue(self):
-        pygame.mixer.music.queue(self.s)
-    
-    class NoneSound:
-            def play(self,loop=0):
-                pass
-            def stop(self):
-                pass
+     """    
     if not pygame.mixer or not pygame.mixer.get_init():
         print >> sys.stderr, 'Cannot load sound, pygame.mixer.error', '\nUsing Nonesound'
         return NoneSound()
-    try:
-       playmusic = MusicObject(file)
-    except (pygame.error,IOError),info:
-        print >> sys.stderr,info,"\nDisable music"
+    if not os.path.exists(file):
+        if UT_DEBUG:
+            print >> sys.stderr, 'Cannot load music: %s \n%s' % (name,pygame.get_error())
+            print >> sys.stderr, 'Using Nonesound'
         playmusic = NoneSound()
+    else:
+        playmusic = MusicObject(file)
+    
+        
     return playmusic
 
 def load_image(file, transparent=0, alpha=0):
@@ -250,7 +262,7 @@ def load_image(file, transparent=0, alpha=0):
     if transparent :
         surface.set_colorkey(surface.get_at((0, 0)), RLEACCEL)
     if alpha:
-        if DEBUG: print "pyassetmlSDL alpha image",file
+        if UT_DEBUG: print "pyassetmlSDL alpha image",file
         #if the image loaded has alpha, the overall alpha set here
         #(128) will be overriden. Do it anyway for forcing RLEACCEL
         surface.set_alpha(128, RLEACCEL)
@@ -524,7 +536,7 @@ class EntryEdit:
         self.hsc_ttf = self.parent.hsc_ttf
         ### RTL mapping related ######
         self.key_map = None # Used as the default keymapping, see function utils.map_keys()
-        if DEBUG: print "self.locale_rtl",self.locale_rtl,"stdloc",self.stdloc
+        if UT_DEBUG: print "self.locale_rtl",self.locale_rtl,"stdloc",self.stdloc
         if self.locale_rtl and self.stdloc:
             self.key_map = {'he':he_key_map,
                         'ar':ar_key_map}[self.stdloc]
@@ -534,9 +546,7 @@ class EntryEdit:
         self.clock = pygame.time.Clock()
         self.pos = pos
         self.maxlen = 16
-        # calaulate maximun length of the enty box
-        # "t" * maxlen seems to give a nice average
-        #s,spam = font2surf(prompt+"t"*self.maxlen,self.sc_fsize,self.sc_fcol,self.hsc_ttf)
+        
         self.rect = pygame.Rect(pos[0],pos[1],700,100)
         
     def _get_key(self):
@@ -545,7 +555,7 @@ class EntryEdit:
             event = pygame.event.poll()
             if event.type == KEYDOWN:
                 m = pygame.key.get_mods()
-                # when using key_maps : < > and ? need spatial care (keys 59,47,46,44)
+                # when using key_maps : < > and ? need special care (keys 59,47,46,44)
                 if self.locale_rtl and event.key == 59 or event.key == 47 or \
                             event.key == 46 or event.key == 44:
                     return event.key
@@ -621,7 +631,7 @@ def __string_split(line, split):
     while line[split] != " " or split == 0:
         split -= 1
     line1 = line[:split]
-    line2 = line[split+1:]
+    line2 = line[split+1:]#loose the space
     
     return line1, line2
 
@@ -709,7 +719,7 @@ class ScaleImages:
                            
         scale_x = int(imgSize[0]/scale_ratio)
         scale_y = int(imgSize[1]/scale_ratio)
-        if DEBUG:
+        if UT_DEBUG:
             print "image size",imgSize
             print "scale ratio",scale_ratio
             print "scale x,y",scale_x,scale_y
@@ -830,6 +840,65 @@ class GfxCursor:
         """
         self.old_pos = event.pos
 
+class ProgressBar:
+    """Class which provides a surface with a progressbar.(400x100)
+    """
+    ## TODO: the progress bar is full after 95 steps, not 100.
+    ## The reason is that it's not possible to split pixels. :-)
+    def __init__(self,start=0,end=100,step=1,header='',ttf=None):
+        """@start is the start value, defaults to 0
+        @end is the end value, defaults to 100
+        @step is the step by which the bar is updated, defaults to 1
+        @header is the text to display above the bar, defaults to ''
+        @ttf is the path to a ttf, defaults to pygame standard font.
+        """
+        self.start = start
+        self.end = end
+        self.step = step
+        self.header = header
+        self.ttf = ttf
+        self.backcol = (0,0,0)
+        self.barfcol = (15,206,14)
+        self.barbcol = (20,20,20)
+        self.headercol = (200,200,200)
+        self.s = pygame.Surface((400,100))
+        self.barpartsurf = pygame.Surface((4,38))
+        self.barpartsurf.fill(self.barfcol)
+        self.barrect = pygame.Rect(10,50,380,40)# relative to self.s
+        self.barsurf = pygame.Surface((self.barrect[2]-2,self.barrect[3]-2))
+        self._initbar()
+                
+    def _initbar(self):
+        self.x,self.progress = self.start,0 # used in update
+        r = (0,0) + self.s.get_size()
+        pygame.draw.rect(self.s,self.headercol,r,1)
+        if self.header:
+            hs = char2surf(self.header,24,self.headercol,self.ttf)
+            self.s.blit(hs,(4 + (400-hs.get_width())/2 ,6))
+        pygame.draw.rect(self.s,self.headercol,self.barrect,1)
+        self.barsurf.fill(self.barbcol)
+        self.s.blit(self.barsurf,(self.barrect[0]+1,self.barrect[1]+1))
+    
+    def update(self):
+        """Update the progressbar with step.
+        Returns the number of steps passed.
+        """
+        if self.progress >= self.end:
+            return self.end
+        for i in range(self.step):
+            self.barsurf.blit(self.barpartsurf,(self.x,0))
+            self.x += self.barpartsurf.get_width()
+            self.progress += 1
+        self.s.blit(self.barsurf,(self.barrect[0]+1,self.barrect[1]+1)) 
+        return self.progress
+    
+    def reset_bar(self):
+        self._initbar()
+    
+    def get_bar(self):
+        return self.s
+        
+
 class ChildsplayGoodies:
     """Class to provide references to a number of objects, methods, functions etc.
     These references are put in here at runtime by the childsplay main module (childsplay.py)
